@@ -1,5 +1,8 @@
 /* contrib/spi/timetravel--1.0.sql */
 
+-- complain if script is sourced in psql, rather than via CREATE EXTENSION
+\echo Use "CREATE EXTENSION timetravel" to load this file. \quit
+
 CREATE FUNCTION timetravel()
 RETURNS trigger
 AS 'MODULE_PATHNAME'
